@@ -10,40 +10,27 @@ from IPython.display import display, HTML
 logger = logging.getLogger(__name__)
 
 STATUS = "status"
-RESULT = "result"
-ERROR = "error"
+DATA = "data"
+ERROR_MESSAGE = "message"
 SUCCESS = "SUCCESS"
 FAILED = "FAILED"
 
-################################################################################
-# Queries
-################################################################################
-
-QUERY_SHOW_DATABASES = """show databases;"""
-QUERY_SHOW_TABLES = """show tables in {schema_name};"""
-QUERY_TABLE_RECORDS_WITH_LIMIT = """select * from {schema_name}.{table_name} limit {limit};"""
-QUERY_TABLE_RECORDS = """select * from {schema_name}.{table_name} limit 100;"""
-
 # Athena services
-API_VALIDATE_USER = "/ccf/services/v2.0/validate_user"
-API_GET_ATHENA_DATABASES = "/ccf/services/v2.0/get_athena_databases"
-API_GET_ATHENA_TABLES = "/ccf/services/v2.0/get_athena_tables"
-API_QUERY_ATHENA_TABLE = "/ccf/services/v2.0/query_athena_table"
-API_RUN_QUERY_ON_ATHENA = "/ccf/services/v2.0/run_query_on_athena"
-API_SAVE_DATA_TO_S3 = "/ccf/services/v2.0/save_data_to_s3"
+API_VALIDATE_USER = "/ccf/services/validate_user"
+API_GET_ATHENA_DATABASES = "/ccf/services/get_athena_databases"
+API_GET_ATHENA_TABLES = "/ccf/services/get_athena_tables"
+API_QUERY_ATHENA_TABLE = "/ccf/services/query_athena_table"
+API_RUN_QUERY_ON_ATHENA = "/ccf/services/run_query_on_athena"
+API_SAVE_DATA_TO_S3 = "/ccf/services/save_data_to_s3"
 
 # Environment Variables
-_USER_NAME: str = 'USER_NAME'
+_USER_ID: str = 'USER_ID'
 _ACCESS_TOKEN: str = 'ACCESS_TOKEN'
-_USER_ROLE: str = 'USER_ROLE'
+_ID_TOKEN: str = 'ID_TOKEN'
+_USER_ROLE_ID: str = 'USER_ROLE'
 _CCF_SERVICES_HOST: str = 'CCF_SERVICES_HOST'
 _USER_S3_BUCKET: str = 'USER_S3_BUCKET'
 
-HEADERS = {
-    'content-type': "application/json",
-    'user-agent': "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
-                  "Chrome/89.0.4389.90 Safari/537.36"
-}
 
 TABLE_STYLES = [dict(selector="caption", props=[("text-align", "inline"), ("font-size", "100%"), ("color", 'black')]),
                 dict(selector="td", props=[('border', '1px solid black'), ("text-align", "left")]),
@@ -56,21 +43,34 @@ TABLE_STYLES = [dict(selector="caption", props=[("text-align", "inline"), ("font
 def connect():
     # TODO - Add user validation
     try:
-        _user_name = os.getenv(_USER_NAME, None)
+        _user_id = os.getenv(_USER_ID, None)
+        _user_role_id = os.getenv(_USER_ROLE_ID, None)
         _access_token = os.getenv(_ACCESS_TOKEN, None)
-        _user_role = os.getenv(_USER_ROLE, None)
-        _ccf_services_host = os.getenv(_CCF_SERVICES_HOST, None)
+        _id_token = os.getenv(_ID_TOKEN, None)
+        _ccf_services_url = os.getenv(_CCF_SERVICES_HOST, None)
         _user_s3_bucket = os.getenv(_USER_S3_BUCKET, None)
-        payload = json.dumps({"user_name": _user_name, "role_id": _user_role})
-        r = requests.post(_ccf_services_host + API_VALIDATE_USER, data=payload, headers=HEADERS,
-                          cookies=dict(sessionId=_access_token))
+
+        _headers = {
+            "content-type": "application/json",
+            "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
+                          "Chrome/89.0.4389.90 Safari/537.36",
+            "userid": _user_id,
+            "roleid": _user_role_id,
+            "idtoken": _id_token,
+            "accesstoken": _access_token
+
+        }
+        _cookie = dict(sessionid=os.getenv(_ACCESS_TOKEN, None))
+
+        r = requests.post(_ccf_services_url + API_VALIDATE_USER, headers=_headers,
+                          cookies=_cookie)
         response = r.json()
         if response[STATUS] == SUCCESS:
-            athena_client = AthenaClient(user_name=_user_name, user_role=_user_role, access_token=_access_token,
-                                         ccf_services_host=_ccf_services_host, user_s3_bucket=_user_s3_bucket)
+            athena_client = AthenaClient(ccf_services_url=_ccf_services_url, headers=_headers, cookie=_cookie,
+                                         user_s3_bucket=_user_s3_bucket)
             return athena_client
         else:
-            print(response[ERROR])
+            print(response[ERROR_MESSAGE])
 
     except requests.exceptions.HTTPError:
         print("Http error occurred")
@@ -84,31 +84,30 @@ def connect():
 
 class AthenaClient:
 
-    def __init__(self, user_name, access_token, user_role, ccf_services_host, user_s3_bucket):
-        self._user_name = user_name
-        self._access_token = access_token
-        self._user_role = user_role
-        self._ccf_services_host = ccf_services_host
+    def __init__(self, ccf_services_url, headers, cookie, user_s3_bucket):
+        self._ccf_services_url = ccf_services_url
+        self._headers = headers
+        self._cookie = cookie
         self._user_s3_bucket = user_s3_bucket
         print("Connection is successful...")
 
     def databases(self, result_as_df=True):
         """Returns all the schemas available in Athena"""
         try:
-            payload = json.dumps({"user_name": self._user_name, "role_id": self._user_role})
-            r = requests.post(self._ccf_services_host + API_GET_ATHENA_DATABASES, data=payload, headers=HEADERS,
-                              cookies=dict(sessionId=self._access_token))
+            payload = json.dumps({})
+            r = requests.post(self._ccf_services_url + API_GET_ATHENA_DATABASES, data=payload, headers=self._headers,
+                              cookies=self._cookie)
             response = r.json()
             if response[STATUS] == SUCCESS:
-                if not result_as_df and isinstance(response[RESULT], (dict, list)):
-                    response_as_df = pd.DataFrame.from_dict(response[RESULT]).style.set_caption(
+                if not result_as_df and isinstance(response[DATA], (dict, list)):
+                    response_as_df = pd.DataFrame.from_dict(response[DATA]).style.set_caption(
                         "Databases").hide_index().set_table_styles(TABLE_STYLES)
                     return display(response_as_df)
                 else:
-                    response_as_df = pd.DataFrame.from_dict(response[RESULT])
+                    response_as_df = pd.DataFrame.from_dict(response[DATA])
                     return response_as_df
             else:
-                return response[ERROR]
+                print(response[ERROR_MESSAGE])
 
         except requests.exceptions.HTTPError:
             print("Http error occurred")
@@ -122,20 +121,20 @@ class AthenaClient:
     def tables(self, schema_name, result_as_df=True):
         """Returns all the tables present in a schema"""
         try:
-            payload = json.dumps({"user_name": self._user_name, "role_id": self._user_role, "schema_name": schema_name})
-            r = requests.post(self._ccf_services_host + API_GET_ATHENA_TABLES, data=payload, headers=HEADERS,
-                              cookies=dict(sessionId=self._access_token))
+            payload = json.dumps({"schema_name": schema_name})
+            r = requests.post(self._ccf_services_url + API_GET_ATHENA_TABLES, data=payload, headers=self._headers,
+                              cookies=self._cookie)
             response = r.json()
             if response[STATUS] == SUCCESS:
-                if not result_as_df and isinstance(response[RESULT], (dict, list)):
-                    response_as_df = pd.DataFrame.from_dict(response[RESULT]).style.set_caption(
+                if not result_as_df and isinstance(response[DATA], (dict, list)):
+                    response_as_df = pd.DataFrame.from_dict(response[DATA]).style.set_caption(
                         "Tables").hide_index().set_table_styles(TABLE_STYLES)
                     return display(response_as_df)
                 else:
-                    response_as_df = pd.DataFrame.from_dict(response[RESULT])
+                    response_as_df = pd.DataFrame.from_dict(response[DATA])
                     return response_as_df
             else:
-                return response[ERROR]
+                print(response[ERROR_MESSAGE])
 
         except requests.exceptions.HTTPError:
             print("Http error occurred")
@@ -149,22 +148,21 @@ class AthenaClient:
     def top(self, schema_name, table_name, limit=None, result_as_df=True):
         """Returns records from a table"""
         try:
-            payload = json.dumps({"user_name": self._user_name, "role_id": self._user_role, "schema_name": schema_name,
-                                  "table_name": table_name, "limit": limit})
-            r = requests.post(self._ccf_services_host + API_QUERY_ATHENA_TABLE, data=payload, headers=HEADERS,
-                              cookies=dict(sessionId=self._access_token))
+            payload = json.dumps({"schema_name": schema_name, "table_name": table_name, "limit": limit})
+            r = requests.post(self._ccf_services_url + API_QUERY_ATHENA_TABLE, data=payload, headers=self._headers,
+                              cookies=self._cookie)
             response = r.json()
             if response[STATUS] == SUCCESS:
-                if not result_as_df and isinstance(response[RESULT], (dict, list)):
+                if not result_as_df and isinstance(response[DATA], (dict, list)):
                     table_header = f'Top {limit} records of table {schema_name}.{table_name}' if limit else f'Top 100 records of table <i>{schema_name}.{table_name}</i>'
-                    response_as_df = pd.DataFrame.from_dict(response[RESULT]).style.set_caption(
+                    response_as_df = pd.DataFrame.from_dict(response[DATA]).style.set_caption(
                         table_header).hide_index().set_table_styles(TABLE_STYLES)
                     return display(response_as_df)
                 else:
-                    response_as_df = pd.DataFrame.from_dict(response[RESULT])
+                    response_as_df = pd.DataFrame.from_dict(response[DATA])
                     return response_as_df
             else:
-                return response[ERROR]
+                print(response[ERROR_MESSAGE])
 
         except requests.exceptions.HTTPError:
             print("Http error occurred")
@@ -178,32 +176,31 @@ class AthenaClient:
     def run_query(self, query_string, result_as_df=True):
         """Run a specified query"""
         try:
-            payload = json.dumps(
-                {"user_name": self._user_name, "role_id": self._user_role, "query_string": query_string})
-            r = requests.post(self._ccf_services_host + API_RUN_QUERY_ON_ATHENA, data=payload, headers=HEADERS,
-                              cookies=dict(sessionId=self._access_token))
+            payload = json.dumps({"query_string": query_string})
+            r = requests.post(self._ccf_services_url + API_RUN_QUERY_ON_ATHENA, data=payload, headers=self._headers,
+                              cookies=self._cookie)
             response = r.json()
             queries = list(filter(None, query_string.split(';')))
             if response[STATUS] == SUCCESS:
-                if not result_as_df and isinstance(response[RESULT], (dict, list)):
+                if not result_as_df and isinstance(response[DATA], (dict, list)):
                     if len(queries) > 1:
                         results = [pd.DataFrame.from_dict(item).style.set_caption(
                             f"""Query results for <i>\"{queries[i]};\"</i>""").hide_index().set_table_styles(TABLE_STYLES) for i, item in
-                                   enumerate(response[RESULT])]
+                                   enumerate(response[DATA])]
                         return display(*results)
                     else:
-                        result = pd.DataFrame.from_dict(response[RESULT]).style.set_caption(
+                        result = pd.DataFrame.from_dict(response[DATA]).style.set_caption(
                             f"""Query results for <i>\"{queries[0]};\"</i>""").hide_index().set_table_styles(
                             TABLE_STYLES)
                         return display(result)
                 else:
                     if len(queries) > 1:
-                        results = [pd.DataFrame.from_dict(item) for item in response[RESULT]]
+                        results = [pd.DataFrame.from_dict(item) for item in response[DATA]]
                     else:
-                        results = pd.DataFrame.from_dict(response[RESULT])
+                        results = pd.DataFrame.from_dict(response[DATA])
                     return results
             else:
-                return response[ERROR]
+                print(response[ERROR_MESSAGE])
 
         except requests.exceptions.HTTPError:
             print("Http error occurred")
@@ -217,16 +214,17 @@ class AthenaClient:
     def save_data(self, data, file_name):
         """Returns records from a table"""
         try:
-            d = data.to_dict(orient='records')
-            payload = json.dumps({"user_name": self._user_name, "role_id": self._user_role, "file_name": file_name,
-                                  "s3_bucket": self._user_s3_bucket, "data": d})
-            r = requests.post(self._ccf_services_host + API_SAVE_DATA_TO_S3, data=payload, headers=HEADERS,
-                              cookies=dict(sessionId=self._access_token))
+            data = data.to_dict(orient='records')
+            if os.path.splitext(file_name)[1] == '':
+                file_name = f'{file_name}.csv'
+            payload = json.dumps({"file_name": file_name, "s3_bucket": self._user_s3_bucket, "data": data})
+            r = requests.post(self._ccf_services_url + API_SAVE_DATA_TO_S3, data=payload, headers=self._headers,
+                              cookies=self._cookie)
             response = r.json()
             if response[STATUS] == SUCCESS:
-                return response[RESULT]
+                return response[DATA]
             else:
-                return response[ERROR]
+                print(response[ERROR_MESSAGE])
 
         except requests.exceptions.HTTPError:
             print("Http error occurred")
